aboutsummaryrefslogtreecommitdiff
path: root/ci/lint/06_script.sh
diff options
context:
space:
mode:
authorDhruv Mehta <856960+dhruv@users.noreply.github.com>2020-12-14 15:55:30 -0800
committerDhruv Mehta <856960+dhruv@users.noreply.github.com>2020-12-15 10:13:55 -0800
commit739d39022d2959c1114c14a0065daebf4fe812c1 (patch)
treeac0c2982e95940bf298dfc6d782be4dd4d685b60 /ci/lint/06_script.sh
parent94a9cd25fd17e10b5720b5f72908b08c0f1ed16d (diff)
downloadbitcoin-739d39022d2959c1114c14a0065daebf4fe812c1.tar.xz
ci: Move linter task to cirrus
Diffstat (limited to 'ci/lint/06_script.sh')
-rwxr-xr-xci/lint/06_script.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/ci/lint/06_script.sh b/ci/lint/06_script.sh
index 6f81ecb22e..ba582e7bf6 100755
--- a/ci/lint/06_script.sh
+++ b/ci/lint/06_script.sh
@@ -6,11 +6,11 @@
export LC_ALL=C
-if [ "$TRAVIS_EVENT_TYPE" = "pull_request" ]; then
- # TRAVIS_BRANCH will be present in a Travis environment. For builds triggered
+if [ -n "$CIRRUS_PR" ]; then
+ # CIRRUS_PR will be present in a Cirrus environment. For builds triggered
# by a pull request this is the name of the branch targeted by the pull request.
- # https://docs.travis-ci.com/user/environment-variables/
- COMMIT_RANGE="$TRAVIS_BRANCH..HEAD"
+ # https://cirrus-ci.org/guide/writing-tasks/#environment-variables
+ COMMIT_RANGE="$CIRRUS_BRANCH..HEAD"
test/lint/commit-script-check.sh $COMMIT_RANGE
fi
@@ -25,8 +25,8 @@ test/lint/check-doc.py
test/lint/check-rpc-mappings.py .
test/lint/lint-all.sh
-if [ "$TRAVIS_REPO_SLUG" = "bitcoin/bitcoin" ] && [ "$TRAVIS_EVENT_TYPE" = "cron" ]; then
+if [ "$CIRRUS_REPO_FULL_NAME" = "bitcoin/bitcoin" ] && [ -n "$CIRRUS_CRON" ]; then
git log --merges --before="2 days ago" -1 --format='%H' > ./contrib/verify-commits/trusted-sha512-root-commit
- travis_retry gpg --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys $(<contrib/verify-commits/trusted-keys) &&
+ ${CI_RETRY_EXE} gpg --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys $(<contrib/verify-commits/trusted-keys) &&
./contrib/verify-commits/verify-commits.py --clean-merge=2;
fi